# Inspect: A Proteomics Search Toolkit

Copyright 2007, The Regents of the University of California

### Table of Contents
- Overview
- Copyright information
- Installation
- Database
- Searching
- Analysis
- Basic Tutorial
- Advanced Tutorial
- Unrestricted Search Tutorial

  MS2DB is a relatively straightforward file format. For now, the documentation is limited to a example.
  TODO: Document all available tags and attributes.

  ### Abbreviated example

      <Database>
      <Gene ExonCount="14" Chromosome="chr1" ForwardFlag="1" Name="At1g02100">
        <Exon Index="0" Start="389875" End="389943">
          <ExonSequence Length="22">MAESRSNRAAVQATNDDASASK</ExonSequence>
        </Exon>
        <Exon Index="1" Start="390036" End="390250">
          <ExonSequence Length="71">SCVKKGYMKDDYVHLFVKRPVRRSPIINRGYFSRWAAFRKLMSQFLLSGTSSKKQILSLGAGFDTTYFQLL</ExonSequence>
          <LinkFrom Index="0" AA="L" />
        </Exon>

      [.......]

        <Exon Index="12" Start="392261" End="392300">
          <ExonSequence Length="13">EHYCVTYAVNDAM</ExonSequence>
          <LinkFrom Index="9" />
        </Exon>
        <Exon Index="13" Start="392373" End="392448">
          <ExonSequence Length="25">GIFGDFGFTREGGGERMSSSASSPX</ExonSequence>
          <LinkFrom Index="12" />
        </Exon>
        <CrossReference Database"Salk" ID="At1g02100.1">
          <CRExons Index="0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 12, 13 />
        </CrossReference>
        <CrossReference Database"Salk" ID="At1g02100.2">
          <CRExons Index="0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 />
        </CrossReference>
      </Gene>
      </Database>